---
name: "\U0001F680 Feature request"
about: Suggest an idea for this project
title: "[Feature Request]"
labels: enhancement
assignees: ''

---

# 🚀 Feature Request

<!-- A clear and concise description of the feature proposal -->

## Motivation

**Is your feature request related to a problem? Please describe.**
<!-- A clear and concise description of what the problem is. Ex. I'm always frustrated when [...] -->
<!-- Please link to any relevant issues or other PRs! -->

## Pitch

**Describe the solution you'd like**
<!-- A clear and concise description of what you want to happen. -->

**Describe alternatives you've considered**
<!-- A clear and concise description of any alternative solutions or features you've considered. -->

**Are you willing to open a pull request?** (We LOVE contributions!!!)

## Additional context

<!-- Add any other context or screenshots about the feature request here. -->
